//
// Copyright (C) 2013-2018 University of Amsterdam
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with this program.  If not, see
// <http://www.gnu.org/licenses/>.
//

import QtQuick
import JASP
import JASP.Controls

Form
{
	Formula
	{
		lhs: "dependent"
		rhs: "modelTerms"
		userMustSpecify: "randomFactors"
	}
	
	IntegerField { visible: false; name: "plotWidthQQPlot"                      ; defaultValue: 300 }
	IntegerField { visible: false; name: "plotHeightQQPlot"                     ; defaultValue: 300 }
	IntegerField { visible: false; name: "plotHeightDescriptivesPlotLegend"     ; defaultValue: 300 }
	IntegerField { visible: false; name: "plotHeightDescriptivesPlotNoLegend"   ; defaultValue: 300 }
	IntegerField { visible: false; name: "plotWidthDescriptivesPlotLegend"      ; defaultValue: 430 }
	IntegerField { visible: false; name: "plotWidthDescriptivesPlotNoLegend"    ; defaultValue: 350 }
	
	VariablesForm
	{
		AvailableVariablesList { name: "allVariablesList" }		
		AssignedVariablesList { name: "dependent";		title: qsTr("Dependent Variables");	allowedColumns: ["scale"]; singleVariable: false		}
		AssignedVariablesList { name: "fixedFactors";	title: qsTr("Fixed Factors");		allowedColumns: ["nominal"]; minLevels: 2				}
		AssignedVariablesList { name: "randomFactors";	title: qsTr("Random Factors");		allowedColumns: ["nominal"]; minLevels: 2;	debug: true }
	}
	
	Section
	{
		title: qsTr("Model")
		
		VariablesForm
		{
			preferredHeight: jaspTheme.smallDefaultVariablesFormHeight
			AvailableVariablesList { name: "components"; title: qsTr("Components"); source: ["fixedFactors", "randomFactors"] }
			AssignedVariablesList {  name: "modelTerms"; title: qsTr("Model Terms"); listViewType: JASP.Interaction }
		}
		CheckBox { name: "includeIntercept";		label: qsTr("Include intercept"); checked: true }
		
	}
	
	
	Section
	{
		title: qsTr("Additional Options")
		
		Group
		{
			title: qsTr("Test")
			CheckBox { name: "testPillai";		label: qsTr("Pillai"); checked: true }
			CheckBox { name: "testWilks";		label: qsTr("Wilks"); checked: false }
			CheckBox { name: "testHotellingLawley";	label: qsTr("Hotelling-Lawley"); checked: false }
			CheckBox { name: "testRoy";		label: qsTr("Roy"); checked: false }
		}
		
		Group
		{
			title: qsTr("Assumption Checks")
			CheckBox { name: "boxMTest";			label: qsTr("Homogeneity of covariance matrices")}
			CheckBox { name: "shapiroTest";			label: qsTr("Multivariate normality")		}
		}
		
		Group
		{
			title: qsTr("Display")
			CheckBox { name: "anovaTables"; label: qsTr("ANOVA tables") }
			CheckBox { name: "vovkSellke"; label: qsTr("Vovk-Sellke maximum p-ratio") }
		}

	
	}
	
}
